# How-To Guides

Task-oriented guides for common workflows.

## Available Guides

- [Run an Audit](audit.md) — Execute quality audits
- [Audit Categories](categories.md) — Available audit categories
- [CI Badge](ci-badge.md) — Add quality badges to your repo
- [Custom Rules](custom-rules.md) — Define custom audit rules
- [MCP Integration](mcp.md) — Use audit tools via MCP
- [Read Results](results.md) — Interpret audit output
- [Troubleshooting](troubleshooting.md) — Common issues and fixes
